//+------------------------------------------------------------------+
//|                                           ChartObjectsArrows.mqh |
//|                        Copyright 2009, MetaQuotes Software Corp. |
//|                                        http://www.metaquotes.net |
//+------------------------------------------------------------------+
//|  .                                                     |
//+------------------------------------------------------------------+
#include "ChartObject.mqh"
//+------------------------------------------------------------------+
//|  CChartObjectArrow.                                         |
//| :    "Arrow".                  |
//+------------------------------------------------------------------+
class CChartObjectArrow : public CChartObject
  {
public:
   //---     
   char              ArrowCode();
   bool              ArrowCode(char code);
   ENUM_ANCHOR_POINT Anchor();
   bool              Anchor(ENUM_ANCHOR_POINT anchor);
   //---   
   bool              Create(long chart_id,string name,int window,datetime time,double price);
   //---   
   virtual int       Type() { return(OBJ_ARROW); };
   //---    
   virtual bool      Save(int file_handle);
   virtual bool      Load(int file_handle);
  };
//+------------------------------------------------------------------+
//|   "Arrow".                                        |
//| INPUT:  chart_id- ,                          |
//|         name    - ,                                    |
//|         window  -  ,                          |
//|         time    - ,                             |
//|         price   - .                                |
//| OUTPUT: true   ,  - false.                |
//| REMARK: .                                                     |
//+------------------------------------------------------------------+
bool CChartObjectArrow::Create(long chart_id,string name,int window,datetime time,double price)
  {
   bool result=ObjectCreate(chart_id,name,OBJ_ARROW,window,time,price);
   if(result) result&=Attach(chart_id,name,window,1);
//---
   return(result);
  }
//+------------------------------------------------------------------+
//|   "".                                          |
//| INPUT:  .                                                     |
//| OUTPUT:  "".                                           |
//| REMARK: .                                                     |
//+------------------------------------------------------------------+
char CChartObjectArrow::ArrowCode()
  {
//--- 
   if(m_chart_id==-1) return(false);
//---
   return((char)ObjectGetInteger(m_chart_id,m_name,OBJPROP_ARROWCODE));
  }
//+------------------------------------------------------------------+
//|   "".                                        |
//| INPUT:  code -  "".                               |
//| OUTPUT: true-  ,  false.                        |
//| REMARK: .                                                     |
//+------------------------------------------------------------------+
bool CChartObjectArrow::ArrowCode(char code)
  {
//--- 
   if(m_chart_id==-1) return(false);
//---
   return(ObjectSetInteger(m_chart_id,m_name,OBJPROP_ARROWCODE,code));
  }
//+------------------------------------------------------------------+
//|    .                                     |
//| INPUT:  .                                                     |
//| OUTPUT:   .                                      |
//| REMARK: .                                                     |
//+------------------------------------------------------------------+
ENUM_ANCHOR_POINT CChartObjectArrow::Anchor()
  {
   return(0);
  }
//+------------------------------------------------------------------+
//|    .                                   |
//| INPUT:  anchor -   .                        |
//| OUTPUT: true-  ,  false.                        |
//| REMARK: .                                                     |
//+------------------------------------------------------------------+
bool CChartObjectArrow::Anchor(ENUM_ANCHOR_POINT anchor)
  {
   return(true);
  }
//+------------------------------------------------------------------+
//|    .                                           |
//| INPUT:  file_handle -     .     |
//| OUTPUT: true  ,  false.                               |
//| REMARK: .                                                     |
//+------------------------------------------------------------------+
bool CChartObjectArrow::Save(int file_handle)
  {
   bool resutl;
//--- 
   if(file_handle<=0) return(false);
   if(m_chart_id==-1) return(false);
//---  
   resutl=CObject::Save(file_handle);
   if(resutl)
     {
      //---   ""
      if(FileWriteInteger(file_handle,ObjectGetInteger(m_chart_id,m_name,OBJPROP_ARROWCODE),CHAR_VALUE)!=sizeof(char)) return(false);
      //---    
      if(FileWriteInteger(file_handle,ObjectGetInteger(m_chart_id,m_name,OBJPROP_ANCHOR),INT_VALUE)!=sizeof(int)) return(false);
     }
//---
   return(resutl);
  }
//+------------------------------------------------------------------+
//|    .                                         |
//| INPUT:  file_handle -     .     |
//| OUTPUT: true  ,  false.                               |
//| REMARK: .                                                     |
//+------------------------------------------------------------------+
bool CChartObjectArrow::Load(int file_handle)
  {
   bool resutl;
//--- 
   if(file_handle<=0) return(false);
   if(m_chart_id==-1) return(false);
//---  
   resutl=CObject::Load(file_handle);
   if(resutl)
     {
      //---   ""
      if(!ObjectSetInteger(m_chart_id,m_name,OBJPROP_ARROWCODE,FileReadInteger(file_handle,CHAR_VALUE))) return(false);
      //---    
      if(!ObjectSetInteger(m_chart_id,m_name,OBJPROP_ANCHOR,FileReadInteger(file_handle,INT_VALUE))) return(false);
     }
//---
   return(resutl);
  }
//+------------------------------------------------------------------+
//|  CChartObjectArrowThumbUp.                                  |
//| :    "Thumbs Up".              |
//+------------------------------------------------------------------+
class CChartObjectArrowThumbUp : public CChartObjectArrow
  {
public:
   //---    
   bool              ArrowCode(char code) { return(false); };
   //---   
   bool              Create(long chart_id,string name,int window,datetime time,double price);
   //---   
   virtual int       Type() { return(OBJ_ARROW_THUMB_UP); };
  };
//+------------------------------------------------------------------+
//|   "Thumbs Up".                                    |
//| INPUT:  chart_id- ,                          |
//|         name    - ,                                    |
//|         window  -  ,                          |
//|         time    - ,                             |
//|         price   - .                                |
//| OUTPUT: true   ,  - false.                |
//| REMARK: .                                                     |
//+------------------------------------------------------------------+
bool CChartObjectArrowThumbUp::Create(long chart_id,string name,int window,datetime time,double price)
  {
   bool result=ObjectCreate(chart_id,name,OBJ_ARROW_THUMB_UP,window,time,price);
   if(result) result&=Attach(chart_id,name,window,1);
//---
   return(result);
  }
//+------------------------------------------------------------------+
//|  CChartObjectArrowThumbDown.                                |
//| :    "Thumbs Down".            |
//+------------------------------------------------------------------+
class CChartObjectArrowThumbDown : public CChartObjectArrow
  {
public:
   //---    
   bool              ArrowCode(char code) { return(false); };
   //---   
   bool              Create(long chart_id,string name,int window,datetime time,double price);
   //---   
   virtual int       Type() { return(OBJ_ARROW_THUMB_DOWN); };
  };
//+------------------------------------------------------------------+
//|   "ThumbsDown".                                   |
//| INPUT:  chart_id- ,                          |
//|         name    - ,                                    |
//|         window  -  ,                          |
//|         time    - ,                             |
//|         price   - .                                |
//| OUTPUT: true   ,  - false.                |
//| REMARK: .                                                     |
//+------------------------------------------------------------------+
bool CChartObjectArrowThumbDown::Create(long chart_id,string name,int window,datetime time,double price)
  {
   bool result=ObjectCreate(chart_id,name,OBJ_ARROW_THUMB_DOWN,window,time,price);
   if(result) result&=Attach(chart_id,name,window,1);
//---
   return(result);
  }
//+------------------------------------------------------------------+
//|  CChartObjectArrowUp.                                       |
//| :    "Arrow Up".               |
//+------------------------------------------------------------------+
class CChartObjectArrowUp : public CChartObjectArrow
  {
public:
   //---    
   bool              ArrowCode(char code) { return(false); };
   //---   
   bool              Create(long chart_id,string name,int window,datetime time,double price);
   //---   
   virtual int       Type() { return(OBJ_ARROW_UP); };
  };
//+------------------------------------------------------------------+
//|   "Arrow Up".                                     |
//| INPUT:  chart_id- ,                          |
//|         name    - ,                                    |
//|         window  -  ,                          |
//|         time    - ,                             |
//|         price   - .                                |
//| OUTPUT: true   ,  - false.                |
//| REMARK: .                                                     |
//+------------------------------------------------------------------+
bool CChartObjectArrowUp::Create(long chart_id,string name,int window,datetime time,double price)
  {
   bool result=ObjectCreate(chart_id,name,OBJ_ARROW_UP,window,time,price);
   if(result) result&=Attach(chart_id,name,window,1);
//---
   return(result);
  }
//+------------------------------------------------------------------+
//|  CChartObjectArrowDown.                                     |
//| :    "Arrow Down".             |
//+------------------------------------------------------------------+
class CChartObjectArrowDown : public CChartObjectArrow
  {
public:
   //---    
   bool              ArrowCode(char code) { return(false); };
   //---   
   bool              Create(long chart_id,string name,int window,datetime time,double price);
   //---   
   virtual int       Type() { return(OBJ_ARROW_DOWN); };
  };
//+------------------------------------------------------------------+
//|   "Arrow Down".                                   |
//| INPUT:  chart_id- ,                          |
//|         name    - ,                                    |
//|         window  -  ,                          |
//|         time    - ,                             |
//|         price   - .                                |
//| OUTPUT: true   ,  - false.                |
//| REMARK: .                                                     |
//+------------------------------------------------------------------+
bool CChartObjectArrowDown::Create(long chart_id,string name,int window,datetime time,double price)
  {
   bool result=ObjectCreate(chart_id,name,OBJ_ARROW_DOWN,window,time,price);
   if(result) result&=Attach(chart_id,name,window,1);
//---
   return(result);
  }
//+------------------------------------------------------------------+
//|  CChartObjectArrowStop.                                     |
//| :    "Stop Sign".              |
//+------------------------------------------------------------------+
class CChartObjectArrowStop : public CChartObjectArrow
  {
public:
   //---    
   bool              ArrowCode(char code) { return(false); };
   //---   
   bool              Create(long chart_id,string name,int window,datetime time,double price);
   //---   
   virtual int       Type() { return(OBJ_ARROW_STOP); };
  };
//+------------------------------------------------------------------+
//|   "Stop Sign".                                    |
//| INPUT:  chart_id- ,                          |
//|         name    - ,                                    |
//|         window  -  ,                          |
//|         time    - ,                             |
//|         price   - .                                |
//| OUTPUT: true   ,  - false.                |
//| REMARK: .                                                     |
//+------------------------------------------------------------------+
bool CChartObjectArrowStop::Create(long chart_id,string name,int window,datetime time,double price)
  {
   bool result=ObjectCreate(chart_id,name,OBJ_ARROW_STOP,window,time,price);
   if(result) result&=Attach(chart_id,name,window,1);
//---
   return(result);
  }
//+------------------------------------------------------------------+
//|  CChartObjectArrowCheck.                                    |
//| :    "Check Sign".             |
//+------------------------------------------------------------------+
class CChartObjectArrowCheck : public CChartObjectArrow
  {
public:
   //---    
   bool              ArrowCode(char code) { return(false); };
   //---   
   bool              Create(long chart_id,string name,int window,datetime time,double price);
   //---   
   virtual int       Type() { return(OBJ_ARROW_CHECK); };
  };
//+------------------------------------------------------------------+
//|   "Check Sign".                                   |
//| INPUT:  chart_id- ,                          |
//|         name    - ,                                    |
//|         window  -  ,                          |
//|         time    - ,                             |
//|         price   - .                                |
//| OUTPUT: true   ,  - false.                |
//| REMARK: .                                                     |
//+------------------------------------------------------------------+
bool CChartObjectArrowCheck::Create(long chart_id,string name,int window,datetime time,double price)
  {
   bool result=ObjectCreate(chart_id,name,OBJ_ARROW_CHECK,window,time,price);
   if(result) result&=Attach(chart_id,name,window,1);
//---
   return(result);
  }
//+------------------------------------------------------------------+
//|  CChartObjectArrowLeftPrice.                                |
//| :    "Left Price Label".       |
//+------------------------------------------------------------------+
class CChartObjectArrowLeftPrice : public CChartObjectArrow
  {
public:
   //---       
   bool              ArrowCode(char code) { return(false); };
   bool              Anchor(ENUM_ANCHOR_POINT anchor) { return(false); };
   //---   
   bool              Create(long chart_id,string name,int window,datetime time,double price);
   //---   
   virtual int       Type() { return(OBJ_ARROW_LEFT_PRICE); };
  };
//+------------------------------------------------------------------+
//|   "Left Price Label".                             |
//| INPUT:  chart_id- ,                          |
//|         name    - ,                                    |
//|         window  -  ,                          |
//|         time    - ,                             |
//|         price   - .                                |
//| OUTPUT: true   ,  - false.                |
//| REMARK: .                                                     |
//+------------------------------------------------------------------+
bool CChartObjectArrowLeftPrice::Create(long chart_id,string name,int window,datetime time,double price)
  {
   bool result=ObjectCreate(chart_id,name,OBJ_ARROW_LEFT_PRICE,window,time,price);
   if(result) result&=Attach(chart_id,name,window,1);
//---
   return(result);
  }
//+------------------------------------------------------------------+
//|  CChartObjectArrowRightPrice.                               |
//| :    "Right Price Label".      |
//+------------------------------------------------------------------+
class CChartObjectArrowRightPrice : public CChartObjectArrow
  {
public:
   //---       
   bool              ArrowCode(char code) { return(false); };
   bool              Anchor(ENUM_ANCHOR_POINT anchor) { return(false); };
   //---   
   bool              Create(long chart_id,string name,int window,datetime time,double price);
   //---   
   virtual int       Type() { return(OBJ_ARROW_RIGHT_PRICE); };
  };
//+------------------------------------------------------------------+
//|   "Right Price Label".                            |
//| INPUT:  chart_id- ,                          |
//|         name    - ,                                    |
//|         window  -  ,                          |
//|         time    - ,                             |
//|         price   - .                                |
//| OUTPUT: true   ,  - false.                |
//| REMARK: .                                                     |
//+------------------------------------------------------------------+
bool CChartObjectArrowRightPrice::Create(long chart_id,string name,int window,datetime time,double price)
  {
   bool result=ObjectCreate(chart_id,name,OBJ_ARROW_RIGHT_PRICE,window,time,price);
   if(result) result&=Attach(chart_id,name,window,1);
//---
   return(result);
  }
//+------------------------------------------------------------------+
